Index: /trunk/include/iprt/cdefs.h
===================================================================
--- /trunk/include/iprt/cdefs.h	(revision 57943)
+++ /trunk/include/iprt/cdefs.h	(revision 57944)
@@ -1447,4 +1447,5 @@
  * @param   b       The 2nd part.
  * @param   c       The 3rd part.
+ * @param   d       The 4th part.
  */
 #define RT_CONCAT4(a,b,c,d)         RT_CONCAT4_HLP(a,b,c,d)
Index: /trunk/include/iprt/cpp/list.h
===================================================================
--- /trunk/include/iprt/cpp/list.h	(revision 57943)
+++ /trunk/include/iprt/cpp/list.h	(revision 57944)
@@ -208,5 +208,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
@@ -924,5 +924,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
@@ -955,5 +955,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
@@ -983,5 +983,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
Index: /trunk/include/iprt/cpp/mtlist.h
===================================================================
--- /trunk/include/iprt/cpp/mtlist.h	(revision 57943)
+++ /trunk/include/iprt/cpp/mtlist.h	(revision 57944)
@@ -101,5 +101,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
@@ -129,5 +129,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
@@ -157,5 +157,5 @@
      * This preallocates @a cCapacity elements within the list.
      *
-     * @param   cCapacitiy   The initial capacity the list has.
+     * @param   cCapacity    The initial capacity the list has.
      * @throws  std::bad_alloc
      */
Index: /trunk/include/iprt/cpp/xml.h
===================================================================
--- /trunk/include/iprt/cpp/xml.h	(revision 57943)
+++ /trunk/include/iprt/cpp/xml.h	(revision 57944)
@@ -601,9 +601,9 @@
      *                              simple path to any decendant.
      * @param   pcszAttribute       The attribute name.
-     * @param   pcszPathNamespace   The namespace to match @pcszPath with, NULL
+     * @param   pcszPathNamespace   The namespace to match @a pcszPath with, NULL
      *                              (default) match any namespace.  When using a
      *                              path, this matches all elements along the way.
-     * @param   pcszAttribNamespace The namespace prefix to apply to the attribute,
-     *                              NULL (default) match any namespace.
+     * @param   pcszAttributeNamespace  The namespace prefix to apply to the
+     *                              attribute, NULL (default) match any namespace.
      * @see     findChildElementP and findAttributeValue
      */
Index: /trunk/include/iprt/dbg.h
===================================================================
--- /trunk/include/iprt/dbg.h	(revision 57943)
+++ /trunk/include/iprt/dbg.h	(revision 57944)
@@ -444,23 +444,23 @@
  * @param   pvUser2             Second user parameter.
  */
-typedef DECLCALLBACK(int) FNDBGCFGOPEN(RTDBGCFG hDbgCfg, const char *pszFilename, void *pvUser1, void *pvUser2);
+typedef DECLCALLBACK(int) FNRTDBGCFGOPEN(RTDBGCFG hDbgCfg, const char *pszFilename, void *pvUser1, void *pvUser2);
 /** Pointer to a open-file callback used to the RTDbgCfgOpen functions. */
-typedef FNDBGCFGOPEN *PFNDBGCFGOPEN;
+typedef FNRTDBGCFGOPEN *PFNRTDBGCFGOPEN;
 
 
 RTDECL(int) RTDbgCfgOpenPeImage(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp,
-                                PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                                PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenPdb70(RTDBGCFG hDbgCfg, const char *pszFilename, PCRTUUID pUuid, uint32_t uAge,
-                              PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                              PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenPdb20(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp, uint32_t uAge,
-                              PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                              PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenDbg(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp,
-                            PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                            PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenDwo(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t uCrc32,
-                            PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                            PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenDsymBundle(RTDBGCFG hDbgCfg, const char *pszFilename, PCRTUUID pUuid,
-                                   PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                                   PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 RTDECL(int) RTDbgCfgOpenMachOImage(RTDBGCFG hDbgCfg, const char *pszFilename, PCRTUUID pUuid,
-                                   PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
+                                   PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2);
 
 
Index: /trunk/include/iprt/getopt.h
===================================================================
--- /trunk/include/iprt/getopt.h	(revision 57943)
+++ /trunk/include/iprt/getopt.h	(revision 57944)
@@ -454,5 +454,5 @@
  * @param   ppwszCmdLine    Where to return the command line string.  This must
  *                          be freed by calling RTUtf16Free.
- * @param   papszArgs       The argument vector to convert.
+ * @param   papszArgv       The argument vector to convert.
  * @param   fFlags          A combination of the RTGETOPTARGV_CNV_XXX flags.
  */
Index: /trunk/include/iprt/mem.h
===================================================================
--- /trunk/include/iprt/mem.h	(revision 57943)
+++ /trunk/include/iprt/mem.h	(revision 57944)
@@ -721,4 +721,6 @@
  *
  * @param   pv      Pointer to memory block.
+ * @param   SRC_POS The source position where call is being made from.  Use
+ *                  RT_SRC_POS when possible.  Optional.
  */
 RTDECL(void)    RTMemEfFree(void *pv, RT_SRC_POS_DECL) RT_NO_THROW_PROTO;
Index: /trunk/include/iprt/sort.h
===================================================================
--- /trunk/include/iprt/sort.h	(revision 57943)
+++ /trunk/include/iprt/sort.h	(revision 57944)
@@ -55,5 +55,5 @@
  * @param   papvArray       The array to sort.
  * @param   cElements       The number of elements in the array.
- * @param   cbElements      The size of an array element.
+ * @param   cbElement       The size of an array element.
  * @param   pfnCmp          Callback function comparing two elements.
  * @param   pvUser          User argument for the callback.
@@ -78,7 +78,7 @@
  * Shell sort an array of variable sized elementes.
  *
- * @param   papvArray       The array to sort.
+ * @param   pvArray         The array to sort.
  * @param   cElements       The number of elements in the array.
- * @param   cbElements      The size of an array element.
+ * @param   cbElement       The size of an array element.
  * @param   pfnCmp          Callback function comparing two elements.
  * @param   pvUser          User argument for the callback.
@@ -101,7 +101,7 @@
  *
  * @returns true if it is sorted, false if it isn't.
- * @param   papvArray       The array to check.
+ * @param   pvArray         The array to check.
  * @param   cElements       The number of elements in the array.
- * @param   cbElements      The size of an array element.
+ * @param   cbElement       The size of an array element.
  * @param   pfnCmp          Callback function comparing two elements.
  * @param   pvUser          User argument for the callback.
Index: /trunk/include/iprt/test.h
===================================================================
--- /trunk/include/iprt/test.h	(revision 57943)
+++ /trunk/include/iprt/test.h	(revision 57944)
@@ -175,5 +175,5 @@
  * @param   phTest      Where to store the test instance handle.
  */
-RTR3DECL(RTEXITCODE) RTTestInitExAndCreate(int cArgs, char ***papszArgs, uint32_t fRtInit, const char *pszTest, PRTTEST phTest);
+RTR3DECL(RTEXITCODE) RTTestInitExAndCreate(int cArgs, char ***ppapszArgs, uint32_t fRtInit, const char *pszTest, PRTTEST phTest);
 
 /**
@@ -540,5 +540,5 @@
  * @param   enmUnit     The value unit.
  * @param   pszNameFmt  The value name format string.
- * @param   va_list     String arguments.
+ * @param   va          String arguments.
  */
 RTR3DECL(int) RTTestValueV(RTTEST hTest, uint64_t u64Value, RTTESTUNIT enmUnit,
@@ -991,5 +991,5 @@
  * @param   enmUnit     The value unit.
  * @param   pszNameFmt  The value name format string.
- * @param   va_list     String arguments.
+ * @param   va          String arguments.
  */
 RTR3DECL(int) RTTestIValueV(uint64_t u64Value, RTTESTUNIT enmUnit, const char *pszNameFmt, va_list va) RT_IPRT_FORMAT_ATTR(3, 0);
@@ -1156,5 +1156,4 @@
  * @param   DetailsArgs     Argument list for RTTestIFailureDetails, including
  *                          parenthesis.
- * @param   rcRet           What to return on failure.
  */
 #define RTTESTI_CHECK_MSG_BREAK(expr, DetailsArgs) \
Index: /trunk/include/iprt/udp.h
===================================================================
--- /trunk/include/iprt/udp.h	(revision 57943)
+++ /trunk/include/iprt/udp.h	(revision 57944)
@@ -132,4 +132,5 @@
  * @param   cbBuffer    Read buffer size.
  * @param   pcbRead     Number of bytes read. Must be non-NULL.
+ * @param   pSrcAddr    The network address to read from.
  */
 RTR3DECL(int)  RTUdpRead(RTSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead, PRTNETADDR pSrcAddr);
Index: /trunk/include/iprt/uint128.h
===================================================================
--- /trunk/include/iprt/uint128.h	(revision 57943)
+++ /trunk/include/iprt/uint128.h	(revision 57944)
@@ -495,6 +495,6 @@
  * Assigns a boolean value to 128-bit unsigned integer.
  *
- * @returns pResult
- * @param   pResult             The result variable.
+ * @returns pValueResult
+ * @param   pValueResult        The result variable.
  * @param   fValue              The boolean value.
  */
@@ -517,6 +517,6 @@
  * Assigns a 8-bit unsigned integer value to 128-bit unsigned integer.
  *
- * @returns pResult
- * @param   pResult             The result variable.
+ * @returns pValueResult
+ * @param   pValueResult        The result variable.
  * @param   u8Value             The 8-bit unsigned integer value.
  */
@@ -539,6 +539,6 @@
  * Assigns a 16-bit unsigned integer value to 128-bit unsigned integer.
  *
- * @returns pResult
- * @param   pResult             The result variable.
+ * @returns pValueResult
+ * @param   pValueResult        The result variable.
  * @param   u16Value            The 16-bit unsigned integer value.
  */
@@ -561,6 +561,6 @@
  * Assigns a 16-bit unsigned integer value to 128-bit unsigned integer.
  *
- * @returns pResult
- * @param   pResult             The result variable.
+ * @returns pValueResult
+ * @param   pValueResult        The result variable.
  * @param   u32Value            The 32-bit unsigned integer value.
  */
@@ -583,7 +583,7 @@
  * Assigns a 64-bit unsigned integer value to 128-bit unsigned integer.
  *
- * @returns pResult
- * @param   pResult             The result variable.
- * @param   u32Value            The 32-bit unsigned integer value.
+ * @returns pValueResult
+ * @param   pValueResult        The result variable.
+ * @param   u64Value            The 64-bit unsigned integer value.
  */
 DECLINLINE(PRTUINT128U) RTUInt128AssignU64(PRTUINT128U pValueResult, uint64_t u64Value)
@@ -834,6 +834,6 @@
  * the result to it.
  *
- * @returns pValue1Result.
- * @param   pValue1Result   The first value and result.
+ * @returns pValueResult.
+ * @param   pValueResult    The first value and result.
  * @param   cBits           The number of bits to shift.
  */
@@ -885,6 +885,6 @@
  * the result to it.
  *
- * @returns pValue1Result.
- * @param   pValue1Result   The first value and result.
+ * @returns pValueResult.
+ * @param   pValueResult    The first value and result.
  * @param   cBits           The number of bits to shift.
  */
Index: /trunk/include/iprt/uri.h
===================================================================
--- /trunk/include/iprt/uri.h	(revision 57943)
+++ /trunk/include/iprt/uri.h	(revision 57944)
@@ -297,5 +297,5 @@
  * @param   pszUri              The URI to extract from.
  * @param   uFormat             In which format should the path returned.
- * @param   cbMax               The max string length to inspect.
+ * @param   cchMax              The max string length to inspect.
  */
 RTDECL(char *) RTUriFileNPath(const char *pszUri, uint32_t uFormat, size_t cchMax);
Index: /trunk/include/iprt/vfs.h
===================================================================
--- /trunk/include/iprt/vfs.h	(revision 57943)
+++ /trunk/include/iprt/vfs.h	(revision 57944)
@@ -227,5 +227,5 @@
  *
  * @returns Referenced handle on success, NIL if the input handle was invalid.
- * @param   hVfsFSs         The VFS filesystem stream handle.
+ * @param   hVfsFss         The VFS filesystem stream handle.
  */
 RTDECL(RTVFSOBJ)        RTVfsObjFromFsStream(RTVFSFSSTREAM hVfsFss);
@@ -298,10 +298,10 @@
  * @retval  VERR_EOF when there are no more objects.
  *
- * @param   pvThis      The implementation specific directory data.
+ * @param   hVfsFss     The file system stream handle.
  * @param   ppszName    Where to return the object name.  Must be freed by
  *                      calling RTStrFree.
  * @param   penmType    Where to return the object type.
- * @param   hVfsObj     Where to return the object handle (referenced).
- *                      This must be cast to the desired type before use.
+ * @param   phVfsObj    Where to return the object handle (referenced). This
+ *                      must be cast to the desired type before use.
  */
 RTDECL(int)         RTVfsFsStrmNext(RTVFSFSSTREAM hVfsFss, char **ppszName, RTVFSOBJTYPE *penmType, PRTVFSOBJ phVfsObj);
@@ -326,5 +326,5 @@
  *
  * @returns New reference count on success (0 if closed), UINT32_MAX on failure.
- * @param   hVfsIos         The VFS directory handle.
+ * @param   hVfsDir         The VFS directory handle.
  */
 RTDECL(uint32_t)    RTVfsDirRelease(RTVFSDIR hVfsDir);
@@ -567,5 +567,5 @@
  * @param   fBlocking       Whether the call is blocking (@c true) or not.  If
  *                          not, the @a pcbWritten parameter must not be NULL.
- * @param   pcbRead         Where to always store the number of bytes actually
+ * @param   pcbWritten      Where to always store the number of bytes actually
  *                          written.  This can be NULL if @a fBlocking is true.
  * @sa      RTVfsFileWrite, RTFileWrite, RTPipeWrite, RTPipeWriteBlocking,
@@ -771,5 +771,5 @@
  *          implementation.
  *
- * @param   hVfsObj         The VFS object handle.
+ * @param   hVfsFile        The VFS file handle.
  * @param   pObjInfo        Where to return the info.
  * @param   enmAddAttr      Which additional attributes should be retrieved.
@@ -801,8 +801,6 @@
  * @param   pvBuf           Where to store the read bytes.
  * @param   cbToRead        The number of bytes to read.
- * @param   fBlocking       Whether the call is blocking (@c true) or not.  If
- *                          not, the @a pcbRead parameter must not be NULL.
  * @param   pcbRead         Where to always store the number of bytes actually
- *                          read.  This can be NULL if @a fBlocking is true.
+ *                          read.  Optional.
  * @sa      RTVfsIoStrmRead, RTFileRead, RTPipeRead, RTPipeReadBlocking,
  *          RTSocketRead
@@ -820,8 +818,6 @@
  * @param   pvBuf           The bytes to write.
  * @param   cbToWrite       The number of bytes to write.
- * @param   fBlocking       Whether the call is blocking (@c true) or not.  If
- *                          not, the @a pcbWritten parameter must not be NULL.
- * @param   pcbRead         Where to always store the number of bytes actually
- *                          written.  This can be NULL if @a fBlocking is true.
+ * @param   pcbWritten      Where to always store the number of bytes actually
+ *                          written.  This can be NULL.
  * @sa      RTVfsIoStrmRead, RTFileWrite, RTPipeWrite, RTPipeWriteBlocking,
  *          RTSocketWrite
@@ -910,5 +906,5 @@
  *
  * The data is read in chunks from @a hVfsIosSrc and written to @a hVfsIosDst
- * until @hVfsIosSrc indicates end of stream.
+ * until @a hVfsIosSrc indicates end of stream.
  *
  * @returns IPRT status code
Index: /trunk/include/iprt/vfslowlevel.h
===================================================================
--- /trunk/include/iprt/vfslowlevel.h	(revision 57943)
+++ /trunk/include/iprt/vfslowlevel.h	(revision 57944)
@@ -237,5 +237,5 @@
  *
  * @returns IPRT status code
- * @param   pVfs Ops            The VFS operations.
+ * @param   pVfsOps             The VFS operations.
  * @param   cbInstance          The size of the instance data.
  * @param   hVfs                The VFS handle to associate this VFS with.
@@ -303,5 +303,5 @@
  *                              object.  The reference is consumed.  NIL and
  *                              special lock handles are fine.
- * @param   phVfsFss            Where to return the new handle.
+ * @param   phVfsObj            Where to return the new handle.
  * @param   ppvInstance         Where to return the pointer to the instance data
  *                              (size is @a cbInstance).
@@ -956,5 +956,4 @@
  *
  * @returns IPRT status code.
- * @param   pvThis      The implementation specific file data.
  * @param   fEvents     The events to poll for (RTPOLL_EVT_XXX).
  * @param   cMillies    How long to wait for event to eventuate.
Index: /trunk/src/VBox/Runtime/Doxyfile
===================================================================
--- /trunk/src/VBox/Runtime/Doxyfile	(revision 57943)
+++ /trunk/src/VBox/Runtime/Doxyfile	(revision 57944)
@@ -1220,4 +1220,5 @@
     DECL_FORCE_INLINE(type)=DECLINLINE(type) \
     DECL_NO_INLINE(type)=type \
+    DECLCALLBACK(type)=type \
     \
     AssertCompile(expr) \
@@ -1261,5 +1262,4 @@
     DECLASM \
     DECLASMTYPE \
-    DECLCALLBACK \
     DECLCALLBACKMEMBER \
     DECLHCCALLBACKMEMBER \
Index: /trunk/src/VBox/Runtime/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Runtime/Makefile.kmk	(revision 57943)
+++ /trunk/src/VBox/Runtime/Makefile.kmk	(revision 57944)
@@ -2731,4 +2731,8 @@
 	$(APPEND) $@.tmp "INCLUDE_FILE_PATTERNS = *.cpp.h"
 	$(APPEND) $@.tmp "PREDEFINED += $(ARCH_BITS_DEFS)"
+	$(APPEND) $@.tmp 'EXCLUDE = '\
+		'$(VBOX_PATH_RUNTIME_SRC)/common/string/unidata-flags.cpp' \
+       	'$(VBOX_PATH_RUNTIME_SRC)/common/string/unidata-lower.cpp' \
+       	'$(VBOX_PATH_RUNTIME_SRC)/common/string/unidata-upper.cpp'
 	$(APPEND) $@.tmp
 	$(APPEND) $@.tmp "INPUT = $(IPRT_DOXYFILE_INPUT)"
Index: /trunk/src/VBox/Runtime/common/dbg/dbgcfg.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgcfg.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgcfg.cpp	(revision 57944)
@@ -451,4 +451,5 @@
  *                              directory.  RTPATH_MAX in size.
  * @param   pszSubDir           The sub directory to append.
+ * @param   pszSuffix           The suffix to append.
  * @param   fCaseInsensitive    Whether case insensitive searching is required.
  */
@@ -568,5 +569,5 @@
 
 static int rtDbgCfgTryOpenDir(PRTDBGCFGINT pThis, char *pszPath, PRTPATHSPLIT pSplitFn, uint32_t fFlags,
-                              PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                              PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     int rcRet = VWRN_NOT_FOUND;
@@ -736,5 +737,5 @@
                                       const char *pszCacheSubDir, const char *pszUuidMappingSubDir,
                                       PRTPATHSPLIT pSplitFn, const char *pszCacheSuffix, uint32_t fFlags,
-                                      PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                      PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
 #ifdef IPRT_WITH_HTTP
@@ -888,5 +889,5 @@
                                 const char *pszCacheSubDir, const char *pszUuidMappingSubDir,
                                 PCRTPATHSPLIT pSplitFn, const char *pszCacheSuffix, uint32_t fFlags,
-                                PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     Assert(pszPath[cchCachePath] == '\0');
@@ -977,5 +978,5 @@
 static int rtDbgCfgTryOpenList(PRTDBGCFGINT pThis, PRTLISTANCHOR pList, PRTPATHSPLIT pSplitFn, const char *pszCacheSubDir,
                                const char *pszUuidMappingSubDir, uint32_t fFlags, char *pszPath,
-                               PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                               PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     int rcRet = VWRN_NOT_FOUND;
@@ -1144,5 +1145,5 @@
 static int rtDbgCfgOpenWithSubDir(RTDBGCFG hDbgCfg, const char *pszFilename, const char *pszCacheSubDir,
                                   const char *pszUuidMappingSubDir, uint32_t fFlags,
-                                  PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                  PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     int rcRet = VINF_SUCCESS;
@@ -1271,5 +1272,5 @@
 
 RTDECL(int) RTDbgCfgOpenPeImage(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp,
-                                PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     char szSubDir[32];
@@ -1283,5 +1284,5 @@
 
 RTDECL(int) RTDbgCfgOpenPdb70(RTDBGCFG hDbgCfg, const char *pszFilename, PCRTUUID pUuid, uint32_t uAge,
-                              PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                              PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     char szSubDir[64];
@@ -1312,5 +1313,5 @@
 
 RTDECL(int) RTDbgCfgOpenPdb20(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp, uint32_t uAge,
-                              PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                              PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     /** @todo test this! */
@@ -1325,5 +1326,5 @@
 
 RTDECL(int) RTDbgCfgOpenDbg(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t cbImage, uint32_t uTimestamp,
-                            PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                            PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     char szSubDir[32];
@@ -1337,5 +1338,5 @@
 
 RTDECL(int) RTDbgCfgOpenDwo(RTDBGCFG hDbgCfg, const char *pszFilename, uint32_t uCrc32,
-                            PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                            PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     char szSubDir[32];
@@ -1361,5 +1362,5 @@
 static int rtDbgCfgTryOpenDsymBundleInDir(PRTDBGCFGINT pThis, char *pszPath, PRTPATHSPLIT pSplitFn,
                                           const char * const *papszSuffixes, uint32_t fFlags,
-                                          PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                          PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     int rcRet = VWRN_NOT_FOUND;
@@ -1450,5 +1451,5 @@
                                        const char *pszCacheSuffix, const char *pszUuidMappingSubDir,
                                        uint32_t fFlags, char *pszPath,
-                                       PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                       PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     int rcRet = VWRN_NOT_FOUND;
@@ -1643,5 +1644,5 @@
                                   const char *pszBundleSubDir, PCRTUUID pUuid, const char *pszUuidMapDirName,
                                   const char *pszCacheSuffix, bool fOpenImage,
-                                  PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                  PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     /*
@@ -1785,5 +1786,5 @@
 
 RTDECL(int) RTDbgCfgOpenDsymBundle(RTDBGCFG hDbgCfg, const char *pszImage, PCRTUUID pUuid,
-                                   PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                   PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     return rtDbgCfgOpenBundleFile(hDbgCfg, pszImage, g_apszDSymBundleSuffixes,
@@ -1795,5 +1796,5 @@
 
 RTDECL(int) RTDbgCfgOpenMachOImage(RTDBGCFG hDbgCfg, const char *pszImage, PCRTUUID pUuid,
-                                   PFNDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
+                                   PFNRTDBGCFGOPEN pfnCallback, void *pvUser1, void *pvUser2)
 {
     return rtDbgCfgOpenBundleFile(hDbgCfg, pszImage, g_apszBundleSuffixes,
@@ -1933,5 +1934,5 @@
  * @param   enmOp               The change operation.
  * @param   pszValue            The input value.
- * @param   pszMnemonics        The mnemonics map for this value.
+ * @param   paMnemonics         The mnemonics map for this value.
  * @param   puValue             The value to change.
  */
@@ -2087,5 +2088,5 @@
  *
  * @returns VINF_SUCCESS, VERR_BUFFER_OVERFLOW.
- * @param   pThis               The config instance.
+ * @param   hDbgCfg             The config instance handle.
  * @param   pList               The string list anchor.
  * @param   pszValue            The output buffer.
@@ -2126,7 +2127,7 @@
  *
  * @returns VINF_SUCCESS, VERR_BUFFER_OVERFLOW.
- * @param   pThis               The config instance.
+ * @param   hDbgCfg             The config instance handle.
  * @param   uValue              The value to query.
- * @param   pszMnemonics        The mnemonics map for this value.
+ * @param   paMnemonics         The mnemonics map for this value.
  * @param   pszValue            The output buffer.
  * @param   cbValue             The size of the output buffer.
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodcodeview.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodcodeview.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodcodeview.cpp	(revision 57944)
@@ -870,5 +870,5 @@
 
 /** @callback_method_impl{FNDBGMODCVSUBSECTCALLBACK,
- * Parses kCvSst_GlobalPub, kCvSst_GlobalSym and kCvSst_StaticSym subsections,
+ * Parses kCvSst_GlobalPub\, kCvSst_GlobalSym and kCvSst_StaticSym subsections\,
  * adding symbols it finds to the container.} */
 static DECLCALLBACK(int)
@@ -898,5 +898,5 @@
 
 /** @callback_method_impl{FNDBGMODCVSUBSECTCALLBACK,
- * Parses kCvSst_Module subsection, storing the debugging style in pThis.} */
+ * Parses kCvSst_Module subsection\, storing the debugging style in pThis.} */
 static DECLCALLBACK(int)
 rtDbgModCvSs_Module(PRTDBGMODCV pThis, void const *pvSubSect, size_t cbSubSect, PCRTCVDIRENT32 pDirEnt)
@@ -929,5 +929,5 @@
 
 /** @callback_method_impl{FNDBGMODCVSUBSECTCALLBACK,
- * Parses kCvSst_Symbols, kCvSst_PublicSym and kCvSst_AlignSym subsections,
+ * Parses kCvSst_Symbols\, kCvSst_PublicSym and kCvSst_AlignSym subsections\,
  * adding symbols it finds to the container.} */
 static DECLCALLBACK(int)
@@ -2182,6 +2182,7 @@
 
 
-/** @callback_method_impl{FNRTLDRENUMSEGS,
- * Used to add segments from the image.}  */
+/**
+ * @callback_method_impl{FNRTLDRENUMSEGS, Used to add segments from the image}
+ */
 static DECLCALLBACK(int) rtDbgModCvAddSegmentsCallback(RTLDRMOD hLdrMod, PCRTLDRSEG pSeg, void *pvUser)
 {
@@ -2373,8 +2374,8 @@
  * @param   pDbgMod             The debug module instance.  On success pvDbgPriv
  *                              will point to a valid RTDBGMODCV.
+ * @param   enmFileType         The kind of file this is we're probing.
  * @param   hFile               The file with debug info in it.
  * @param   off                 The offset where to expect CV debug info.
  * @param   cb                  The number of bytes of debug info.
- * @param   enmArch             The desired image architecture.
  * @param   pszFilename         The path to the file (for logging).
  */
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmoddwarf.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmoddwarf.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmoddwarf.cpp	(revision 57944)
@@ -591,5 +591,5 @@
  * @param   pDesc           The attribute descriptor.
  * @param   uForm           The data form.
- * @param   pDataCursor     The cursor to read data from.
+ * @param   pCursor         The cursor to read data from.
  */
 typedef DECLCALLBACK(int) FNRTDWARFATTRDECODER(PRTDWARFDIE pDie, uint8_t *pbMember, PCRTDWARFATTRDESC pDesc,
@@ -1976,5 +1976,5 @@
  *          uErrValue is returned.
  * @param   pCursor             The cursor.
- * @param   uErrValue           What to return on error.
+ * @param   iErrValue           What to return on error.
  */
 static int8_t rtDwarfCursor_GetSByte(PRTDWARFCURSOR pCursor, int8_t iErrValue)
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodexports.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodexports.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodexports.cpp	(revision 57944)
@@ -56,5 +56,5 @@
 
 /** @callback_method_impl{FNRTLDRENUMSYMS,
- *  Copies the symbols over into the container.} */
+ *      Copies the symbols over into the container} */
 static DECLCALLBACK(int) rtDbgModExportsAddSymbolCallback(RTLDRMOD hLdrMod, const char *pszSymbol, unsigned uSymbol,
                                                           RTLDRADDR Value, void *pvUser)
@@ -76,5 +76,5 @@
 
 /** @callback_method_impl{FNRTLDRENUMSEGS,
- *  Copies the segments over into the container.} */
+ *      Copies the segments over into the container} */
 static DECLCALLBACK(int) rtDbgModExportsAddSegmentsCallback(RTLDRMOD hLdrMod, PCRTLDRSEG pSeg, void *pvUser)
 {
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodldr.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodldr.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodldr.cpp	(revision 57944)
@@ -124,6 +124,6 @@
 
 
-/** @interface_method_impl{RTDBGMODVTIMG,pfnGetLoadedSize} */
-static DECLCALLBACK(RTUINTPTR) rtDbgModLdr_GetLoadedSize(PRTDBGMODINT pMod)
+/** @interface_method_impl{RTDBGMODVTIMG,pfnImageSize} */
+static DECLCALLBACK(RTUINTPTR) rtDbgModLdr_ImageSize(PRTDBGMODINT pMod)
 {
     PRTDBGMODLDR pThis = (PRTDBGMODLDR)pMod->pvImgPriv;
@@ -216,5 +216,5 @@
     /*.pfnEnumSegments = */             rtDbgModLdr_EnumSegments,
     /*.pfnEnumSymbols = */              rtDbgModLdr_EnumSymbols,
-    /*.pfnGetLoadedSize = */            rtDbgModLdr_GetLoadedSize,
+    /*.pfnImageSize = */                rtDbgModLdr_ImageSize,
     /*.pfnLinkAddressToSegOffset = */   rtDbgModLdr_LinkAddressToSegOffset,
     /*.pfnRvaToSegOffset= */            rtDbgModLdr_RvaToSegOffset,
Index: /trunk/src/VBox/Runtime/common/math/bignum.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/math/bignum.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/math/bignum.cpp	(revision 57944)
@@ -2076,6 +2076,6 @@
  * @param   pauDividendJ    Pointer to the j-th (normalized) dividend element.
  *                          Will access up to two elements prior to this.
- * @param   uDivZ           The last element in the (normalized) divisor.
- * @param   uDivY           The penultimate element in the (normalized) divisor.
+ * @param   pauDivisor      The last element in the (normalized) divisor.
+ * @param   cDivisor        The penultimate element in the (normalized) divisor.
  */
 DECLINLINE(void) rtBigNumKnuthD6_AddBack(PRTBIGNUMELEMENT pauDividendJ, PRTBIGNUMELEMENT pauDivisor, uint32_t cDivisor)
Index: /trunk/src/VBox/Runtime/common/misc/aiomgr.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/aiomgr.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/misc/aiomgr.cpp	(revision 57944)
@@ -244,5 +244,5 @@
  * @returns TRUE if there are still requests pending on the current manager for this endpoint.
  *          FALSE otherwise.
- * @param   pEndpointRemove    The endpoint to remove.
+ * @param   pFile           The endpoint to remove.
  */
 static bool rtAioMgrFileRemove(PRTAIOMGRFILEINT pFile)
Index: /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp	(revision 57944)
@@ -1127,7 +1127,6 @@
  *          first retainer.  NIL_RTLOCKVALCLASS if we run into trouble.
  *
- * @param   pszFile             The source position of the call, file.
- * @param   iLine               The source position of the call, line.
- * @param   pszFunction         The source position of the call, function.
+ * @param   SRC_POS             The source position where call is being made from.
+ *                              Use RT_SRC_POS when possible.  Optional.
  * @param   pszNameFmt          Class name format string, optional (NULL).  Max
  *                              length is 32 bytes.
Index: /trunk/src/VBox/Runtime/common/path/RTPathGlob.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/path/RTPathGlob.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/path/RTPathGlob.cpp	(revision 57944)
@@ -238,4 +238,55 @@
 
 
+/**
+ * Matching variable lookup table.
+ * Currently so small we don't bother sorting it and doing binary lookups.
+ */
+typedef struct RTPATHMATCHVAR
+{
+    /** The variable name. */
+    const char     *pszName;
+    /** The variable name length. */
+    uint16_t        cchName;
+    /** Only available as the verify first component.  */
+    bool            fFirstOnly;
+
+    /**
+     * Queries a given variable value.
+     *
+     * @returns IPRT status code.
+     * @retval  VERR_BUFFER_OVERFLOW
+     * @retval  VERR_TRY_AGAIN if the caller should skip this value item and try the
+     *          next one instead (e.g. env var not present).
+     * @retval  VINF_EOF when retrieving the last one, if possible.
+     * @retval  VERR_EOF when @a iItem is past the item space.
+     *
+     * @param   iItem       The variable value item to retrieve. (A variable may
+     *                      have more than one value, e.g. 'BothProgramFile' on a
+     *                      64-bit system or 'Path'.)
+     * @param   pszBuf      Where to return the value.
+     * @param   cbBuf       The buffer size.
+     * @param   pcchValue   Where to return the length of the return string.
+     * @param   pCache      Pointer to the path matching cache.  May speed up
+     *                      enumerating PATH items and similar.
+     */
+    DECLCALLBACKMEMBER(int, pfnQuery)(uint32_t iItem, char *pszBuf, size_t cbBuf, size_t *pcchValue, PRTPATHMATCHCACHE pCache);
+
+    /**
+     * Matching method, optional.
+     *
+     * @returns IPRT status code.
+     * @retval  VINF_SUCCESS on match.
+     * @retval  VERR_MISMATCH on mismatch.
+     *
+     * @param   pszMatch    String to match with (not terminated).
+     * @param   cchMatch    The length of what we match with.
+     * @param   fIgnoreCase Whether to ignore case or not when comparing.
+     * @param   pcchMatched Where to return the length of the match (value length).
+     */
+    DECLCALLBACKMEMBER(int, pfnMatch)(const char *pchMatch, size_t cchMatch, bool fIgnoreCase, size_t *pcchMatched);
+
+} RTPATHMATCHVAR;
+
+
 /*********************************************************************************************************************************
 *   Internal Functions                                                                                                           *
@@ -400,5 +451,5 @@
 
 /**
- * @interface_method_impl{RTPATHMATCHVAR::pfnQuery, Enumerates the PATH}.
+ * @interface_method_impl{RTPATHMATCHVAR,pfnQuery, Enumerates the PATH}.
  */
 static DECLCALLBACK(int) rtPathVarQuery_Path(uint32_t iItem, char *pszBuf, size_t cbBuf, size_t *pcchValue,
@@ -488,5 +539,5 @@
 #if defined(RT_OS_WINDOWS) || defined(RT_OS_OS2)
 /**
- * @interface_method_impl{RTPATHMATCHVAR::pfnQuery,
+ * @interface_method_impl{RTPATHMATCHVAR,pfnQuery,
  *      The system drive letter + colon.}.
  */
@@ -540,5 +591,5 @@
 #ifdef RT_OS_WINDOWS
 /**
- * @interface_method_impl{RTPATHMATCHVAR::pfnQuery,
+ * @interface_method_impl{RTPATHMATCHVAR,pfnQuery,
  *      The system root directory (C:\Windows).}.
  */
@@ -565,52 +616,9 @@
 
 /**
- * Matching variable lookup table.
- * Currently so small we don't bother sorting it and doing binary lookups.
- */
-static struct RTPATHMATCHVAR
-{
-    /** The variable name. */
-    const char     *pszName;
-    /** The variable name length. */
-    uint16_t        cchName;
-    /** Only available as the verify first component.  */
-    bool            fFirstOnly;
-
-    /**
-     * Queries a given variable value.
-     *
-     * @returns IPRT status code.
-     * @retval  VERR_BUFFER_OVERFLOW
-     * @retval  VERR_TRY_AGAIN if the caller should skip this value item and try the
-     *          next one instead (e.g. env var not present).
-     * @retval  VINF_EOF when retrieving the last one, if possible.
-     * @retval  VERR_EOF when @a iItem is past the item space.
-     *
-     * @param   iItem       The variable value item to retrieve. (A variable may
-     *                      have more than one value, e.g. 'BothProgramFile' on a
-     *                      64-bit system or 'Path'.)
-     * @param   pszBuf      Where to return the value.
-     * @param   cbBuf       The buffer size.
-     * @param   pcchValue   Where to return the length of the return string.
-     * @param   pCache      Pointer to the path matching cache.  May speed up
-     *                      enumerating PATH items and similar.
-     */
-    DECLCALLBACKMEMBER(int, pfnQuery)(uint32_t iItem, char *pszBuf, size_t cbBuf, size_t *pcchValue, PRTPATHMATCHCACHE pCache);
-
-    /**
-     * Matching method, optional.
-     *
-     * @returns IPRT status code.
-     * @retval  VINF_SUCCESS on match.
-     * @retval  VERR_MISMATCH on mismatch.
-     *
-     * @param   pszMatch    String to match with (not terminated).
-     * @param   cchMatch    The length of what we match with.
-     * @param   fIgnoreCase Whether to ignore case or not when comparing.
-     * @param   pcchMatched Where to return the length of the match (value length).
-     */
-    DECLCALLBACKMEMBER(int, pfnMatch)(const char *pchMatch, size_t cchMatch, bool fIgnoreCase, size_t *pcchMatched);
-
-} const g_aVariables[] =
+ *
+ *
+ * @author bird (9/29/2015)
+ */
+static RTPATHMATCHVAR const g_aVariables[] =
 {
     { RT_STR_TUPLE("Arch"),                     false,  rtPathVarQuery_Arch, rtPathVarMatch_Arch },
Index: /trunk/src/VBox/Runtime/common/string/strformat.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/string/strformat.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/string/strformat.cpp	(revision 57944)
@@ -555,5 +555,5 @@
                             while (cchStr-- > 0)
                             {
-/**@todo #ifndef IN_RC*/
+/**@todo \#ifndef IN_RC*/
 #ifdef IN_RING3
                                 RTUNICP Cp;
@@ -589,5 +589,5 @@
                             while (cchStr-- > 0)
                             {
-/**@todo #ifndef IN_RC*/
+/**@todo \#ifndef IN_RC*/
 #ifdef IN_RING3
                                 char szUtf8[8]; /* Cp=0x7fffffff -> 6 bytes. */
Index: /trunk/src/VBox/Runtime/common/string/uniread.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/string/uniread.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/string/uniread.cpp	(revision 57944)
@@ -712,6 +712,7 @@
  * Applies a property to a code point.
  *
- * @param   StartCP     The code point.
- * @param   pszProperty The property name.
+ * @param   StartCP         The code point.
+ * @param   pszProperty     The property name.
+ * @param   pszNextField    The next field.
  */
 static void ApplyProperty(RTUNICP StartCP, const char *pszProperty, char *pszNextField)
Index: /trunk/src/VBox/Runtime/common/string/utf-8.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/string/utf-8.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/string/utf-8.cpp	(revision 57944)
@@ -870,5 +870,5 @@
  *
  * @returns iprt status code.
- * @param   psz         The Latin-1 string.
+ * @param   pszIn       The Latin-1 string.
  * @param   cchIn       The number of characters to process from psz. The recoding
  *                      will stop when cch or '\\0' is reached.
Index: /trunk/src/VBox/Runtime/common/time/timesup.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/time/timesup.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/common/time/timesup.cpp	(revision 57944)
@@ -112,5 +112,5 @@
 
 /**
- * @interface_method_impl{RTTIMENANOTSDATA, pfnBad}
+ * @interface_method_impl{RTTIMENANOTSDATA,pfnBad}
  */
 static DECLCALLBACK(void) rtTimeNanoTSInternalBitch(PRTTIMENANOTSDATA pData, uint64_t u64NanoTS, uint64_t u64DeltaPrev,
@@ -127,5 +127,5 @@
 
 /**
- * @interface_method_impl{RTTIMENANOTSDATA, pfnBadCpuIndex}
+ * @interface_method_impl{RTTIMENANOTSDATA,pfnBadCpuIndex}
  */
 static DECLCALLBACK(uint64_t) rtTimeNanoTSInternalBadCpuIndex(PRTTIMENANOTSDATA pData, uint16_t idApic,
Index: /trunk/src/VBox/Runtime/generic/http-curl.cpp
===================================================================
--- /trunk/src/VBox/Runtime/generic/http-curl.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/generic/http-curl.cpp	(revision 57944)
@@ -177,5 +177,5 @@
 *   Defined Constants And Macros                                                                                                 *
 *********************************************************************************************************************************/
-/** @def RTHTTP_MAX_MEM_DOWNLOAD
+/** @def RTHTTP_MAX_MEM_DOWNLOAD_SIZE
  * The max size we are allowed to download to a memory buffer.
  *
@@ -598,5 +598,6 @@
  * Configures a proxy given a "URL" like specification.
  *
- * Format is [<scheme>"://"][<userid>[@<password>]:]<server>[":"<port>].
+ * Format is:
+ * <pre> [<scheme>"://"][<userid>[@<password>]:]<server>[":"<port>] </pre>
  *
  * @returns IPRT status code.
Index: /trunk/src/VBox/Runtime/r3/solaris/coredumper-solaris.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/solaris/coredumper-solaris.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/solaris/coredumper-solaris.cpp	(revision 57944)
@@ -399,5 +399,6 @@
  *
  * @param pSolCore          Pointer to the core object.
- * @param pszFileFmt        Only the name of the file to read from (/proc/<pid> will be prepended)
+ * @param pszProcFileName   Only the name of the file to read from
+ *                          (/proc/\<pid\> will be prepended)
  * @param ppv               Where to store the allocated buffer.
  * @param pcb               Where to store size of the buffer.
@@ -513,8 +514,8 @@
  * Read process credential information (format prcred_t + array of guid_t)
  *
+ * @return IPRT status code.
  * @param pSolCore          Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadCred(PRTSOLCORE pSolCore)
@@ -530,8 +531,8 @@
  * Read process privilege information (format prpriv_t + array of priv_chunk_t)
  *
+ * @return IPRT status code.
  * @param pSolCore          Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadPriv(PRTSOLCORE pSolCore)
@@ -556,8 +557,8 @@
  * Read process LDT information (format array of struct ssd) from /proc.
  *
- * @param pSolProc         Pointer to the core object.
+ * @return  IPRT status code.
+ * @param   pSolCore        Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadLdt(PRTSOLCORE pSolCore)
@@ -573,8 +574,8 @@
  * Read process auxiliary vectors (format auxv_t) for the process.
  *
+ * @return IPRT status code.
  * @param pSolCore          Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadAuxVecs(PRTSOLCORE pSolCore)
@@ -663,8 +664,8 @@
  * Read the process mappings (format prmap_t array).
  *
+ * @return IPRT status code.
  * @param   pSolCore            Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadMappings(PRTSOLCORE pSolCore)
@@ -801,8 +802,8 @@
  * Reads the thread information for all threads in the process.
  *
+ * @return IPRT status code.
  * @param pSolCore          Pointer to the core object.
  *
  * @remarks Should not be called before successful call to @see AllocMemoryArea()
- * @return IPRT status code.
  */
 static int ProcReadThreads(PRTSOLCORE pSolCore)
@@ -1843,4 +1844,5 @@
  * to be in suspended state (i.e. called after CreateCore).
  *
+ * @return IPRT status.
  * @param pSolCore          Pointer to the core object.
  * @param pfnWriter         Pointer to the writer function to override default writer (NULL uses default).
@@ -1848,5 +1850,4 @@
  * @remarks Resumes all suspended threads, unless it's an invalid core. This
  *          function must be called only -after- rtCoreDumperCreateCore().
- * @return IPRT status.
  */
 static int rtCoreDumperWriteCore(PRTSOLCORE pSolCore, PFNRTCOREWRITER pfnWriter)
@@ -1913,4 +1914,5 @@
  * are ultimately resumed en-masse) already suspended while calling this function.
  *
+ * @return IPRT status code.
  * @param pSolCore          Pointer to a core object.
  * @param pContext          Pointer to the caller context thread.
@@ -1919,5 +1921,4 @@
  *
  * @remarks Halts all threads.
- * @return IPRT status code.
  */
 static int rtCoreDumperCreateCore(PRTSOLCORE pSolCore, ucontext_t *pContext, const char *pszCoreFilePath)
Index: /trunk/src/VBox/Runtime/r3/stream.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/stream.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/stream.cpp	(revision 57944)
@@ -90,5 +90,5 @@
     /** Whether the stream was opened in binary mode. */
     bool                fBinary;
-    /** Whether to recheck the stream mode before writing.. */
+    /** Whether to recheck the stream mode before writing. */
     bool                fRecheckMode;
 #ifndef HAVE_FWRITE_UNLOCKED
Index: /trunk/src/VBox/Runtime/r3/tcp.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/tcp.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/tcp.cpp	(revision 57944)
@@ -156,5 +156,5 @@
  * @returns The old handle value.
  * @param   phSock          The socket handle variable to update.
- * @param   hSock           The new socket handle value.
+ * @param   hNew            The new socket handle value.
  */
 DECLINLINE(RTSOCKET) rtTcpAtomicXchgSock(RTSOCKET volatile *phSock, const RTSOCKET hNew)
Index: /trunk/src/VBox/Runtime/r3/test.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/test.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/test.cpp	(revision 57944)
@@ -427,11 +427,11 @@
 
 
-RTR3DECL(RTEXITCODE) RTTestInitExAndCreate(int cArgs, char ***papszArgs, uint32_t fRtInit, const char *pszTest, PRTTEST phTest)
+RTR3DECL(RTEXITCODE) RTTestInitExAndCreate(int cArgs, char ***ppapszArgs, uint32_t fRtInit, const char *pszTest, PRTTEST phTest)
 {
     int rc;
-    if (cArgs <= 0 && papszArgs == NULL)
+    if (cArgs <= 0 && ppapszArgs == NULL)
         rc = RTR3InitExeNoArguments(fRtInit);
     else
-        rc = RTR3InitExe(cArgs, papszArgs, fRtInit);
+        rc = RTR3InitExe(cArgs, ppapszArgs, fRtInit);
     if (RT_FAILURE(rc))
     {
Index: /trunk/src/VBox/Runtime/r3/udp.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/udp.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/udp.cpp	(revision 57944)
@@ -128,5 +128,5 @@
  * @returns The old handle value.
  * @param   phSock          The socket handle variable to update.
- * @param   hSock           The new socket handle value.
+ * @param   hNew            The new socket handle value.
  */
 DECLINLINE(RTSOCKET) rtUdpAtomicXchgSock(RTSOCKET volatile *phSock, const RTSOCKET hNew)
Index: /trunk/src/VBox/Runtime/r3/xml.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 57943)
+++ /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 57944)
@@ -1440,6 +1440,6 @@
  * that was either created or changed.
  *
- * @param pcszName
- * @param i
+ * @param   pcszName    The attribute name.
+ * @param   f           The attribute value.
  * @return
  */
@@ -1458,5 +1458,5 @@
  * @param   pListAnchor Pointer to the m_children member of the parent.  NULL
  *                      for the root node.
- * @param   pLibNode    Pointer to the libxml2 node structure.
+ * @param   pLibAttr    Pointer to the libxml2 attribute structure.
  */
 AttributeNode::AttributeNode(const ElementNode *pElmRoot,

Index: /trunk/include/iprt/cpp/ministring.h
===================================================================
--- /trunk/include/iprt/cpp/ministring.h	(revision 57943)
+++ /trunk/include/iprt/cpp/ministring.h	(revision 57944)
@@ -428,11 +428,11 @@
      * Shortcut to append(), char variant.
      *
-     * @param pszThat           The character to append.
+     * @param ch                The character to append.
      *
      * @returns                 Reference to the object.
      */
-    RTCString &operator+=(char c)
-    {
-        return append(c);
+    RTCString &operator+=(char ch)
+    {
+        return append(ch);
     }
 
@@ -603,14 +603,14 @@
      * Compares the member string to another RTCString.
      *
      * @param   pcszThat    The string to compare with.
      * @param   cs          Whether comparison should be case-sensitive.
      * @returns 0 if equal, negative if this is smaller than @a pcsz, positive
      *          if larger.
      */
-    int compare(const RTCString &that, CaseSensitivity cs = CaseSensitive) const
+    int compare(const RTCString &rThat, CaseSensitivity cs = CaseSensitive) const
     {
         if (cs == CaseSensitive)
-            return ::RTStrCmp(m_psz, that.m_psz);
-        return ::RTStrICmp(m_psz, that.m_psz);
+            return ::RTStrCmp(m_psz, rThat.m_psz);
+        return ::RTStrICmp(m_psz, rThat.m_psz);
     }
 
@@ -619,10 +619,10 @@
      *
      * @returns true if equal, false if not.
-     * @param   that    The string to compare with.
-     */
-    bool equals(const RTCString &that) const
-    {
-        return that.length() == length()
-            && memcmp(that.m_psz, m_psz, length()) == 0;
+     * @param   rThat    The string to compare with.
+     */
+    bool equals(const RTCString &rThat) const
+    {
+        return rThat.length() == length()
+            && memcmp(rThat.m_psz, m_psz, length()) == 0;
     }
 
@@ -603,14 +603,14 @@
      * Compares the member string to another RTCString.
      *
-     * @param   pcszThat    The string to compare with.
+     * @param   rThat       The string to compare with.
      * @param   cs          Whether comparison should be case-sensitive.
      * @returns 0 if equal, negative if this is smaller than @a pcsz, positive
Index: /trunk/include/iprt/ldr.h
===================================================================
--- /trunk/include/iprt/ldr.h	(revision 57943)
+++ /trunk/include/iprt/ldr.h	(revision 57944)
@@ -635,7 +635,7 @@
  * @param   pvUser          The user argument specified to RTLdrEnumSymbols().
  */
-typedef DECLCALLBACK(int) RTLDRENUMSYMS(RTLDRMOD hLdrMod, const char *pszSymbol, unsigned uSymbol, RTLDRADDR Value, void *pvUser);
-/** Pointer to a RTLDRENUMSYMS() callback function. */
-typedef RTLDRENUMSYMS *PFNRTLDRENUMSYMS;
+typedef DECLCALLBACK(int) FNRTLDRENUMSYMS(RTLDRMOD hLdrMod, const char *pszSymbol, unsigned uSymbol, RTLDRADDR Value, void *pvUser);
+/** Pointer to a FNRTLDRENUMSYMS() callback function. */
+typedef FNRTLDRENUMSYMS *PFNRTLDRENUMSYMS;
 
 /**
@@ -931,5 +931,5 @@
  *
  * @param   hLdrMod         The module handle.
- * @param   Rva             The segment index.
+ * @param   iSeg            The segment index.
  * @param   offSeg          The segment offset.
  * @param   pRva            Where to return the RVA.
@@ -1071,5 +1071,5 @@
  *                          Optional.
  */
-RTDECL(int) RTLdrQueryPropEx(RTLDRMOD hLdrMod, RTLDRPROP enmProp, void *pvBits, void *pvBuf, size_t cbBuf, size_t *pcbBuf);
+RTDECL(int) RTLdrQueryPropEx(RTLDRMOD hLdrMod, RTLDRPROP enmProp, void *pvBits, void *pvBuf, size_t cbBuf, size_t *pcbRet);
 
 
Index: /trunk/include/iprt/tcp.h
===================================================================
--- /trunk/include/iprt/tcp.h	(revision 57943)
+++ /trunk/include/iprt/tcp.h	(revision 57944)
@@ -53,9 +53,9 @@
  * @returns VERR_TCP_SERVER_STOP to terminate the server loop forcing
  *          the RTTcpCreateServer() call to return.
  * @param   Sock        The socket which the client is connected to.
  *                      The call will close this socket.
  * @param   pvUser      User argument.
  */
-typedef DECLCALLBACK(int) FNRTTCPSERVE(RTSOCKET Sock, void *pvUser);
+typedef DECLCALLBACK(int) FNRTTCPSERVE(RTSOCKET hSocket, void *pvUser);
 /** Pointer to a RTTCPSERVE(). */
 typedef FNRTTCPSERVE *PFNRTTCPSERVE;
@@ -213,7 +213,7 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
- */
-RTR3DECL(int) RTTcpClientClose(RTSOCKET Sock);
+ * @param   hSocket     Socket descriptor.
+ */
+RTR3DECL(int) RTTcpClientClose(RTSOCKET hSocket);
 
 /**
@@ -228,5 +228,5 @@
  *                              further ado.
  */
-RTR3DECL(int) RTTcpClientCloseEx(RTSOCKET Sock, bool fGracefulShutdown);
+RTR3DECL(int) RTTcpClientCloseEx(RTSOCKET hSocket, bool fGracefulShutdown);
 
 /**
@@ -234,5 +234,5 @@
  *
  * @returns iprt status code.
  * @param   Sock        Socket descriptor.
  * @param   pvBuffer    Where to put the data we read.
  * @param   cbBuffer    Read buffer size.
@@ -241,5 +241,5 @@
  *                      If not NULL a partial read can be done successfully.
  */
-RTR3DECL(int)  RTTcpRead(RTSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead);
+RTR3DECL(int)  RTTcpRead(RTSOCKET hSocket, void *pvBuffer, size_t cbBuffer, size_t *pcbRead);
 
 /**
@@ -249,9 +249,9 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
  * @param   Sock        Socket descriptor.
  * @param   pvBuffer    Buffer to write data to socket.
  * @param   cbBuffer    How much to write.
  */
-RTR3DECL(int)  RTTcpWrite(RTSOCKET Sock, const void *pvBuffer, size_t cbBuffer);
+RTR3DECL(int)  RTTcpWrite(RTSOCKET hSocket, const void *pvBuffer, size_t cbBuffer);
 
 /**
@@ -259,7 +259,7 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
- */
-RTR3DECL(int)  RTTcpFlush(RTSOCKET Sock);
+ * @param   hSocket     Socket descriptor.
+ */
+RTR3DECL(int)  RTTcpFlush(RTSOCKET hSocket);
 
 /**
@@ -270,8 +270,8 @@
  *
  * @returns iprt status code.
  * @param   Sock        Socket descriptor.
  * @param   fEnable     When set to true enables coalescing.
  */
-RTR3DECL(int)  RTTcpSetSendCoalescing(RTSOCKET Sock, bool fEnable);
+RTR3DECL(int)  RTTcpSetSendCoalescing(RTSOCKET hSocket, bool fEnable);
 
 /**
@@ -280,9 +280,9 @@
  *
  * @returns iprt status code.
  * @param   Sock        Socket descriptor.
  * @param   cMillies    Number of milliseconds to wait for the socket.
  *                      Use RT_INDEFINITE_WAIT to wait for ever.
  */
-RTR3DECL(int)  RTTcpSelectOne(RTSOCKET Sock, RTMSINTERVAL cMillies);
+RTR3DECL(int)  RTTcpSelectOne(RTSOCKET hSocket, RTMSINTERVAL cMillies);
 
 /**
@@ -291,5 +291,5 @@
  *
  * @returns iprt status code.
  * @param   Sock        Socket descriptor.
  * @param   fEvents     Event mask to wait for.
  *                      Use the RTSOCKET_EVT_* defines.
@@ -298,6 +298,5 @@
  *                      Use RT_INDEFINITE_WAIT to wait for ever.
  */
-RTR3DECL(int)  RTTcpSelectOneEx(RTSOCKET Sock, uint32_t fEvents, uint32_t *pfEvents,
-                                RTMSINTERVAL cMillies);
+RTR3DECL(int)  RTTcpSelectOneEx(RTSOCKET hSocket, uint32_t fEvents, uint32_t *pfEvents, RTMSINTERVAL cMillies);
 
 #if 0 /* skipping these for now - RTTcpServer* handles this. */
@@ -306,9 +305,9 @@
  *
  * @returns iprt status code.
  * @param   Sock        Socket descriptor.
  * @param   cBackLog    The maximum length the queue of pending connections
  *                      may grow to.
  */
-RTR3DECL(int)  RTTcpListen(RTSOCKET Sock, int cBackLog);
+RTR3DECL(int)  RTTcpListen(RTSOCKET hSocket, int cBackLog);
 
 /**
@@ -316,9 +315,9 @@
  *
  * @returns iprt status code.
  * @param   Sock            Socket descriptor.
  * @param   uPort           The port for accepting connection.
  * @param   pSockAccepted   Where to store the handle to the accepted connection.
  */
-RTR3DECL(int)  RTTcpAccept(RTSOCKET Sock, unsigned uPort, PRTSOCKET pSockAccepted);
+RTR3DECL(int)  RTTcpAccept(RTSOCKET hSocket, unsigned uPort, PRTSOCKET pSockAccepted);
 
 #endif
@@ -328,8 +327,8 @@
  *
  * @returns IPRT status code.
  * @param   Sock            Socket descriptor.
  * @param   pAddr           Where to store the local address on success.
  */
-RTR3DECL(int) RTTcpGetLocalAddress(RTSOCKET Sock, PRTNETADDR pAddr);
+RTR3DECL(int) RTTcpGetLocalAddress(RTSOCKET hSocket, PRTNETADDR pAddr);
 
 /**
@@ -337,8 +336,8 @@
  *
  * @returns IPRT status code.
  * @param   Sock            Socket descriptor.
  * @param   pAddr           Where to store the peer address on success.
  */
-RTR3DECL(int) RTTcpGetPeerAddress(RTSOCKET Sock, PRTNETADDR pAddr);
+RTR3DECL(int) RTTcpGetPeerAddress(RTSOCKET hSocket, PRTNETADDR pAddr);
 
 /**
@@ -348,8 +347,8 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
  * @param   Sock        Socket descriptor.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  */
-RTR3DECL(int)  RTTcpSgWrite(RTSOCKET Sock, PCRTSGBUF pSgBuf);
+RTR3DECL(int)  RTTcpSgWrite(RTSOCKET hSocket, PCRTSGBUF pSgBuf);
 
 
@@ -399,10 +398,10 @@
  * @returns IPRT status code.
  *
  * @param   Sock        Socket descriptor.
  * @param   pvBuffer    Where to put the data we read.
  * @param   cbBuffer    Read buffer size.
  * @param   pcbRead     Number of bytes read.
  */
-RTR3DECL(int)  RTTcpReadNB(RTSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead);
+RTR3DECL(int)  RTTcpReadNB(RTSOCKET hSocket, void *pvBuffer, size_t cbBuffer, size_t *pcbRead);
 
 /**
@@ -413,10 +412,10 @@
  * @returns IPRT status code.
  *
  * @param   Sock        Socket descriptor.
  * @param   pvBuffer    Buffer to write data to socket.
  * @param   cbBuffer    How much to write.
  * @param   pcbWritten  Number of bytes written.
  */
-RTR3DECL(int)  RTTcpWriteNB(RTSOCKET Sock, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten);
+RTR3DECL(int)  RTTcpWriteNB(RTSOCKET hSocket, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten);
 
 /**
@@ -428,9 +427,9 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
  * @param   Sock        Socket descriptor.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  * @param   pcbWritten  Number of bytes written.
  */
-RTR3DECL(int)  RTTcpSgWriteNB(RTSOCKET Sock, PCRTSGBUF pSgBuf, size_t *pcbWritten);
+RTR3DECL(int)  RTTcpSgWriteNB(RTSOCKET hSocket, PCRTSGBUF pSgBuf, size_t *pcbWritten);
 
 
@@ -53,9 +53,9 @@
  * @returns VERR_TCP_SERVER_STOP to terminate the server loop forcing
  *          the RTTcpCreateServer() call to return.
- * @param   Sock        The socket which the client is connected to.
- *                      The call will close this socket.
+ * @param   hSocket     The socket which the client is connected to. The call
+ *                      will close this socket.
  * @param   pvUser      User argument.
  */
@@ -234,5 +234,5 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pvBuffer    Where to put the data we read.
  * @param   cbBuffer    Read buffer size.
@@ -249,9 +249,9 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pvBuffer    Buffer to write data to socket.
  * @param   cbBuffer    How much to write.
@@ -270,8 +270,8 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   fEnable     When set to true enables coalescing.
  */
@@ -280,9 +280,9 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   cMillies    Number of milliseconds to wait for the socket.
  *                      Use RT_INDEFINITE_WAIT to wait for ever.
@@ -291,5 +291,5 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   fEvents     Event mask to wait for.
  *                      Use the RTSOCKET_EVT_* defines.
@@ -306,9 +305,9 @@
  *
  * @returns iprt status code.
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   cBackLog    The maximum length the queue of pending connections
  *                      may grow to.
@@ -316,9 +315,9 @@
  *
  * @returns iprt status code.
- * @param   Sock            Socket descriptor.
+ * @param   hSocket         Socket descriptor.
  * @param   uPort           The port for accepting connection.
  * @param   pSockAccepted   Where to store the handle to the accepted connection.
@@ -328,8 +327,8 @@
  *
  * @returns IPRT status code.
- * @param   Sock            Socket descriptor.
+ * @param   hSocket         Socket descriptor.
  * @param   pAddr           Where to store the local address on success.
  */
@@ -337,8 +336,8 @@
  *
  * @returns IPRT status code.
- * @param   Sock            Socket descriptor.
+ * @param   hSocket         Socket descriptor.
  * @param   pAddr           Where to store the peer address on success.
  */
@@ -348,8 +347,8 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  */
@@ -399,10 +398,10 @@
  * @returns IPRT status code.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pvBuffer    Where to put the data we read.
  * @param   cbBuffer    Read buffer size.
@@ -413,10 +412,10 @@
  * @returns IPRT status code.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pvBuffer    Buffer to write data to socket.
  * @param   cbBuffer    How much to write.
@@ -428,9 +427,9 @@
  * @retval  VERR_INTERRUPTED if interrupted before anything was written.
  *
- * @param   Sock        Socket descriptor.
+ * @param   hSocket     Socket descriptor.
  * @param   pSgBuf      Scatter/gather buffer to write data to socket.
  * @param   pcbWritten  Number of bytes written.
Index: /trunk/src/VBox/Runtime/include/internal/dbgmod.h
===================================================================
--- /trunk/src/VBox/Runtime/include/internal/dbgmod.h	(revision 57943)
+++ /trunk/src/VBox/Runtime/include/internal/dbgmod.h	(revision 57944)
@@ -233,5 +233,5 @@
      * @returns IPRT status code.
      * @param   pMod            Pointer to the module structure.
-     * @param   enmLdrProp      The property to query.
+     * @param   enmProp         The property to query.
      * @param   pvBuf           Pointer to the return buffer.
      * @param   cbBuf           The size of the return buffer.
@@ -524,8 +524,8 @@
  * @returns IPRT status code. On success the necessary method tables should be
  *          installed in @a pMod.
  * @param   pMod            Pointer to the debug module structure.
  * @param   pDeferred       The deferred load data.
  */
-typedef DECLCALLBACK(int) FNRTDBGMODDEFERRED(PRTDBGMODINT pMod, struct RTDBGMODDEFERRED *pDeferred);
+typedef DECLCALLBACK(int) FNRTDBGMODDEFERRED(PRTDBGMODINT pDbgMod, struct RTDBGMODDEFERRED *pDeferred);
 /** Pointer to a deferred loading callback. */
 typedef FNRTDBGMODDEFERRED *PFNRTDBGMODDEFERRED;
@@ -524,8 +524,8 @@
  * @returns IPRT status code. On success the necessary method tables should be
  *          installed in @a pMod.
- * @param   pMod            Pointer to the debug module structure.
+ * @param   pDbgMod         Pointer to the debug module structure.
  * @param   pDeferred       The deferred load data.
  */